@@ -332,7 +332,7 @@ def main(args):
     # the following code will be removed in future
     try:
         print "++++++++++++++++++++++++++++++++"
-        print "****  %f\t%s\t%s" % \
+        print "!!!!  %f\t%s\t%s" % \
             (eval_res['map'].mean(0),
             '\t'.join(["%f" % x for x in eval_res['preck'].mean(0)]),
             '\t'.join(["%f" % x for x in eval_res['recallk'].mean(0)]))
